@@ -1,4 +1,4 @@
 var c = ICanvasRenderingContext2D(root.lookup("/device/canvas"));
 
-c.setFillStyle("rgba(255, 255, 255, 1)");
+c.fillStyle = "rgba(255, 255, 255, 1)";
 c.fillRect(0, 0, 1024, 768);
