@@ -1,5 +1,5 @@
 // The current UTC.
-stdout = System.getOut();
+stdout = System.output;
 s = "Automatic test is UNSUPPORTED.\n";
 stdout.write(s, s.length);
 
