@@ -1,7 +1,7 @@
 // check Date(number)
 function check(result)
 {
-    stdout = System.getOut();
+    stdout = System.output;
     if (result)
     {
         stdout.write("OK\n", 3);
@@ -13,7 +13,7 @@ function check(result)
     return result;
 }
 
-stdout = System.getOut();
+stdout = System.output;
 
 stdout.write("origin: ", 8);
 d = new Date(0);
