@@ -1,6 +1,6 @@
 // test setMinutes().
 
-stdout = System.getOut();
+stdout = System.output;
 function check(result)
 {
     if (result)
