@@ -1,5 +1,5 @@
 // test setMilliseconds().
-stdout = System.getOut();
+stdout = System.output;
 function check(result)
 {
     if (result)
