@@ -1,4 +1,4 @@
-stdout = System.getOut();
+stdout = System.output;
 function check(result)
 {
     if (result)
