@@ -33,7 +33,7 @@ function invalidCompare(x, y)
 
 function check(result)
 {
-    stdout = System.getOut();
+    stdout = System.output;
     if (result)
     {
         stdout.write("OK\n", 3);
