@@ -1,12 +1,12 @@
-stdin = System.getIn();
-stdout = System.getOut();
-root = System.getRoot();
+stdin = System.input;
+stdout = System.output;
+root = System.root;
 
 iter = root.list("");
 while (iter.hasNext())
 {
     file = IFile(iter.next());
-    name = file.getName(256);
+    name = file.name;
     stdout.write(name + '\n', name.length + 1);
 }
 "Ok";
