@@ -56,7 +56,7 @@ public:
         int getCount();
 
         // IInterface
-        bool queryInterface(const Guid& riid, void** objectPtr);
+        void* queryInterface(const Guid& riid);
         unsigned int addRef(void);
         unsigned int release(void);
 
