@@ -54,7 +54,7 @@ public:
     {
         return true;
     }
-    bool getPromiscuousMode()
+    bool isPromiscuousMode()
     {
         return true;
     }
@@ -92,7 +92,7 @@ public:
     void flush();
 
     // IInterface
-    bool queryInterface(const Guid& riid, void** objectPtr);
+    void* queryInterface(const Guid& riid);
     unsigned int addRef();
     unsigned int release();
 };
