@@ -329,8 +329,8 @@ issue(AtaDevice* device, u8* packet, int packetSize,
         return -1;
     }
 
-    outpb(ctlPort + DEVICE_CONTROL, 0);
     wait();
+
     outpb(ctlPort + DEVICE_CONTROL, NIEN);
     return count;
 }
@@ -459,6 +459,7 @@ invoke(int param)
             break;
         case PACKET:
             int len;
+            outpb(ctlPort + DEVICE_CONTROL, 0);
             switch (inpb(cmdPort + INTERRUPT_REASON) & (/*Rel|*/ IO | CD))
             {
               case CD:      // transfer the packet
@@ -535,9 +536,8 @@ AtaController(int cmdPort, int ctlPort, int irq, AtaDma* dma, IContext* ata) :
 {
     device[0] = device[1] = 0;
 
-    esCreateInstance(CLSID_Monitor,
-                     IID_IMonitor,
-                     reinterpret_cast<void**>(&monitor));
+    monitor = reinterpret_cast<IMonitor*>(
+        esCreateInstance(CLSID_Monitor, IMonitor::iid()));
 
     if (!softwareReset())
     {
@@ -620,24 +620,24 @@ AtaController::
     monitor->release();
 }
 
-bool AtaController::
-queryInterface(const Guid& riid, void** objectPtr)
+void* AtaController::
+queryInterface(const Guid& riid)
 {
-    if (riid == IID_ICallback)
+    void* objectPtr;
+    if (riid == ICallback::iid())
     {
-        *objectPtr = static_cast<ICallback*>(this);
+        objectPtr = static_cast<ICallback*>(this);
     }
-    else if (riid == IID_IInterface)
+    else if (riid == IInterface::iid())
     {
-        *objectPtr = static_cast<ICallback*>(this);
+        objectPtr = static_cast<ICallback*>(this);
     }
     else
     {
-        *objectPtr = NULL;
-        return false;
+        return NULL;
     }
-    static_cast<IInterface*>(*objectPtr)->addRef();
-    return true;
+    static_cast<IInterface*>(objectPtr)->addRef();
+    return objectPtr;
 }
 
 unsigned int AtaController::
