@@ -16,6 +16,8 @@
 #include <es/clsid.h>
 #include <es/exception.h>
 #include <es/synchronized.h>
+
+using namespace es;
 #include "line.h"
 
 Line::
@@ -26,9 +28,8 @@ Line(ICallback* callback, u8 bits, u8 channels, u8 rate) :
     rate(rate),
     ring(buffer, sizeof buffer)
 {
-    esCreateInstance(CLSID_Monitor,
-                     IID_IMonitor,
-                     reinterpret_cast<void**>(&monitor));
+    monitor = reinterpret_cast<IMonitor*>(
+        esCreateInstance(CLSID_Monitor, IMonitor::iid()));
 }
 
 Line::
@@ -122,32 +123,32 @@ write(const void* src, int count, long long offset)
     esThrow(EACCES);
 }
 
-bool Line::
-queryInterface(const Guid& riid, void** objectPtr)
+void* Line::
+queryInterface(const Guid& riid)
 {
-    if (riid == IID_ICallback)
+    void* objectPtr;
+    if (riid == ICallback::iid())
     {
-        *objectPtr = static_cast<ICallback*>(this);
+        objectPtr = static_cast<ICallback*>(this);
     }
-    else if (riid == IID_IStream)
+    else if (riid == IStream::iid())
     {
-        *objectPtr = static_cast<IStream*>(this);
+        objectPtr = static_cast<IStream*>(this);
     }
-    else if (riid == IID_IAudioFormat)
+    else if (riid == IAudioFormat::iid())
     {
-        *objectPtr = static_cast<IAudioFormat*>(this);
+        objectPtr = static_cast<IAudioFormat*>(this);
     }
-    else if (riid == IID_IInterface)
+    else if (riid == IInterface::iid())
     {
-        *objectPtr = static_cast<ICallback*>(this);
+        objectPtr = static_cast<ICallback*>(this);
     }
     else
     {
-        *objectPtr = NULL;
-        return false;
+        return NULL;
     }
-    static_cast<IInterface*>(*objectPtr)->addRef();
-    return true;
+    static_cast<IInterface*>(objectPtr)->addRef();
+    return objectPtr;
 }
 
 unsigned int Line::
