@@ -129,28 +129,28 @@ void Loopback::flush()
 // IInterface
 //
 
-bool Loopback::
-queryInterface(const Guid& riid, void** objectPtr)
+void* Loopback::
+queryInterface(const Guid& riid)
 {
-    if (riid == IID_IStream)
+    void* objectPtr;
+    if (riid == IStream::iid())
     {
-        *objectPtr = static_cast<IStream*>(this);
+        objectPtr = static_cast<IStream*>(this);
     }
-    else if (riid == IID_INetworkInterface)
+    else if (riid == INetworkInterface::iid())
     {
-        *objectPtr = static_cast<INetworkInterface*>(this);
+        objectPtr = static_cast<INetworkInterface*>(this);
     }
-    else if (riid == IID_IInterface)
+    else if (riid == IInterface::iid())
     {
-        *objectPtr = static_cast<IStream*>(this);
+        objectPtr = static_cast<IStream*>(this);
     }
     else
     {
-        *objectPtr = NULL;
-        return false;
+        return NULL;
     }
-    static_cast<IInterface*>(*objectPtr)->addRef();
-    return true;
+    static_cast<IInterface*>(objectPtr)->addRef();
+    return objectPtr;
 }
 
 unsigned int Loopback::
