@@ -43,9 +43,8 @@ Tap::Tap(const char* ifName, const char* bridge, const char* script) : ref(0), f
 
     getBridgeMacAddress();
 
-    esCreateInstance(CLSID_Monitor,
-                     IID_IMonitor,
-                     reinterpret_cast<void**>(&monitor));
+    monitor = reinterpret_cast<IMonitor*>(
+        esCreateInstance(CLSID_Monitor, IMonitor::iid()));
 }
 
 Tap::~Tap()
@@ -207,28 +206,28 @@ getMacAddress(unsigned char* mac)
 // IInterface
 //
 
-bool Tap::
-queryInterface(const Guid& riid, void** objectPtr)
+void* Tap::
+queryInterface(const Guid& riid)
 {
-    if (riid == IID_IStream)
+    void* objectPtr;
+    if (riid == IStream::iid())
     {
-        *objectPtr = static_cast<IStream*>(this);
+        objectPtr = static_cast<IStream*>(this);
     }
-    else if (riid == IID_INetworkInterface)
+    else if (riid == INetworkInterface::iid())
     {
-        *objectPtr = static_cast<INetworkInterface*>(this);
+        objectPtr = static_cast<INetworkInterface*>(this);
     }
-    else if (riid == IID_IInterface)
+    else if (riid == IInterface::iid())
     {
-        *objectPtr = static_cast<INetworkInterface*>(this);
+        objectPtr = static_cast<INetworkInterface*>(this);
     }
     else
     {
-        *objectPtr = NULL;
-        return false;
+        return NULL;
     }
-    static_cast<IInterface*>(*objectPtr)->addRef();
-    return true;
+    static_cast<IInterface*>(objectPtr)->addRef();
+    return objectPtr;
 }
 
 unsigned int Tap::
