@@ -100,9 +100,8 @@ public:
         addr(addr),
         replied(false)
     {
-        esCreateInstance(CLSID_Monitor,
-                         IID_IMonitor,
-                         reinterpret_cast<void**>(&monitor));
+        monitor = reinterpret_cast<IMonitor*>(
+            esCreateInstance(CLSID_Monitor, IMonitor::iid()));
     }
     ~ICMPEchoReplyReceiver()
     {
