@@ -603,9 +603,8 @@ public:
 
         listening(0)
     {
-        esCreateInstance(CLSID_Monitor,
-                         IID_IMonitor,
-                         reinterpret_cast<void**>(&monitor));
+        monitor = reinterpret_cast<IMonitor*>(
+            esCreateInstance(CLSID_Monitor, IMonitor::iid()));
 
         initRto();
     }
