@@ -780,23 +780,23 @@ public:
         return enabled;
     }
 
-    bool queryInterface(const Guid& riid, void** objectPtr)
+    void* queryInterface(const Guid& riid)
     {
-        if (riid == IID_IService)
+        void* objectPtr;
+        if (riid == IService::iid())
         {
-            *objectPtr = static_cast<IService*>(this);
+            objectPtr = static_cast<IService*>(this);
         }
-        else if (riid == IID_IInterface)
+        else if (riid == IInterface::iid())
         {
-            *objectPtr = static_cast<IService*>(this);
+            objectPtr = static_cast<IService*>(this);
         }
         else
         {
-            *objectPtr = NULL;
-            return false;
+            return NULL;
         }
-        static_cast<IInterface*>(*objectPtr)->addRef();
-        return true;
+        static_cast<IInterface*>(objectPtr)->addRef();
+        return objectPtr;
     }
 
     unsigned int addRef(void)
